pub struct Bot {
pub api: String,
}Fields
api: StringTrait Implementations
Sourceimpl EventHandler for Bot
impl EventHandler for Bot
Sourcefn interaction_create<'life0, 'async_trait>(
&'life0 self,
ctx: Context,
interaction: Interaction,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn interaction_create<'life0, 'async_trait>(
&'life0 self,
ctx: Context,
interaction: Interaction,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dispatched when an interaction is created (e.g a slash command was used or a button was clicked). Read more
Sourcefn ready<'life0, 'async_trait>(
&'life0 self,
ctx: Context,
ready: Ready,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn ready<'life0, 'async_trait>(
&'life0 self,
ctx: Context,
ready: Ready,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dispatched upon startup. Read more
Sourcefn application_command_permissions_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_permission: CommandPermission,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn application_command_permissions_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_permission: CommandPermission,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the permissions of an application command was updated. Read more
Sourcefn auto_moderation_rule_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_rule: Rule,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn auto_moderation_rule_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_rule: Rule,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when an auto moderation rule was created. Read more
Sourcefn auto_moderation_rule_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_rule: Rule,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn auto_moderation_rule_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_rule: Rule,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when an auto moderation rule was updated. Read more
Sourcefn auto_moderation_rule_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_rule: Rule,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn auto_moderation_rule_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_rule: Rule,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when an auto moderation rule was deleted. Read more
Sourcefn auto_moderation_action_execution<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_execution: ActionExecution,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn auto_moderation_action_execution<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_execution: ActionExecution,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when an auto moderation rule was triggered and an action was executed. Read more
Sourcefn channel_create<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel: &'life1 GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn channel_create<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel: &'life1 GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Dispatched when a channel is created. Read more
Sourcefn category_create<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_category: &'life1 ChannelCategory,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn category_create<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_category: &'life1 ChannelCategory,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Dispatched when a category is created. Read more
Sourcefn category_delete<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_category: &'life1 ChannelCategory,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn category_delete<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_category: &'life1 ChannelCategory,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Dispatched when a category is deleted. Read more
Sourcefn channel_delete<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel: &'life1 GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn channel_delete<'life0, 'life1, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel: &'life1 GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Dispatched when a channel is deleted. Read more
Sourcefn channel_pins_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_pin: ChannelPinsUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn channel_pins_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_pin: ChannelPinsUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a pin is added, deleted. Read more
Sourcefn channel_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: Channel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn channel_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: Channel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a channel is updated. Read more
Sourcefn guild_ban_addition<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_banned_user: User,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_ban_addition<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_banned_user: User,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user is banned from a guild. Read more
Sourcefn guild_ban_removal<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_unbanned_user: User,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_ban_removal<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_unbanned_user: User,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user’s ban is lifted from a guild. Read more
Sourcefn guild_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild: Guild,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild: Guild,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild is created;
or an existing guild’s data is sent to us. Read more
Sourcefn guild_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_incomplete: UnavailableGuild,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_incomplete: UnavailableGuild,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild is deleted. Read more
Sourcefn guild_emojis_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_current_state: HashMap<EmojiId, Emoji>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_emojis_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_current_state: HashMap<EmojiId, Emoji>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the emojis are updated. Read more
Sourcefn guild_integrations_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_integrations_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild’s integration is added, updated or removed. Read more
Sourcefn guild_member_addition<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_member: Member,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_member_addition<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_member: Member,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user joins a guild. Read more
Sourcefn guild_member_removal<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_kicked: User,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_member_removal<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_kicked: User,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user’s membership ends by leaving, getting kicked, or being banned. Read more
Sourcefn guild_member_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new: GuildMemberUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_member_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new: GuildMemberUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a member is updated (e.g their nickname is updated). Read more
Sourcefn guild_members_chunk<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_chunk: GuildMembersChunkEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_members_chunk<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_chunk: GuildMembersChunkEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the data for offline members was requested. Read more
Sourcefn guild_role_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new: Role,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_role_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new: Role,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a role is created. Read more
Sourcefn guild_role_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_removed_role_id: RoleId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_role_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_removed_role_id: RoleId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a role is deleted. Read more
Sourcefn guild_role_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: Role,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_role_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: Role,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a role is updated. Read more
Sourcefn guild_stickers_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_current_state: HashMap<StickerId, Sticker>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_stickers_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_current_state: HashMap<StickerId, Sticker>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the stickers are updated. Read more
Dispatched when a guild became unavailable. Read more
Sourcefn guild_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_but_incomplete_data: PartialGuild,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_but_incomplete_data: PartialGuild,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the guild is updated. Read more
Sourcefn invite_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_data: InviteCreateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn invite_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_data: InviteCreateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a invite is created. Read more
Sourcefn invite_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_data: InviteDeleteEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn invite_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_data: InviteDeleteEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a invite is deleted. Read more
Sourcefn message<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_message: Message,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn message<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_message: Message,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a message is created. Read more
Sourcefn message_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel_id: ChannelId,
_deleted_message_id: MessageId,
_guild_id: Option<GuildId>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn message_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel_id: ChannelId,
_deleted_message_id: MessageId,
_guild_id: Option<GuildId>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a message is deleted. Read more
Sourcefn message_delete_bulk<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel_id: ChannelId,
_multiple_deleted_messages_ids: Vec<MessageId>,
_guild_id: Option<GuildId>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn message_delete_bulk<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel_id: ChannelId,
_multiple_deleted_messages_ids: Vec<MessageId>,
_guild_id: Option<GuildId>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when multiple messages were deleted at once. Read more
Sourcefn message_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: MessageUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn message_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: MessageUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a message is updated. Read more
Sourcefn reaction_add<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_add_reaction: Reaction,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn reaction_add<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_add_reaction: Reaction,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a new reaction is attached to a message. Read more
Sourcefn reaction_remove<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_removed_reaction: Reaction,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn reaction_remove<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_removed_reaction: Reaction,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a reaction is detached from a message. Read more
Sourcefn reaction_remove_all<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel_id: ChannelId,
_removed_from_message_id: MessageId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn reaction_remove_all<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_channel_id: ChannelId,
_removed_from_message_id: MessageId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when all reactions of a message are detached from a message. Read more
Sourcefn presence_replace<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: Vec<Presence>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn presence_replace<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: Vec<Presence>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
This event is legacy, and likely no longer sent by discord.
Sourcefn presence_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: Presence,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn presence_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: Presence,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user’s presence is updated (e.g off -> on). Read more
Sourcefn resume<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: ResumedEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn resume<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: ResumedEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched upon reconnection.
Sourcefn shard_stage_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: ShardStageUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn shard_stage_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: ShardStageUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a shard’s connection stage is updated Read more
Sourcefn typing_start<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: TypingStartEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn typing_start<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: TypingStartEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user starts typing.
Sourcefn unknown<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_name: String,
_raw: Value,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn unknown<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_name: String,
_raw: Value,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when an unknown event was sent from discord. Read more
Sourcefn user_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: CurrentUser,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn user_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_new_data: CurrentUser,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the bot’s data is updated. Read more
Sourcefn voice_server_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: VoiceServerUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn voice_server_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: VoiceServerUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild’s voice server was updated (or changed to another one). Read more
Sourcefn voice_state_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: VoiceState,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn voice_state_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
__arg2: VoiceState,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a user joins, leaves or moves to a voice channel. Read more
Sourcefn webhook_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_belongs_to_channel_id: ChannelId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn webhook_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_guild_id: GuildId,
_belongs_to_channel_id: ChannelId,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild’s webhook is updated. Read more
Sourcefn integration_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_integration: Integration,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn integration_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_integration: Integration,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild integration is created. Read more
Sourcefn integration_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_integration: Integration,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn integration_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_integration: Integration,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild integration is updated. Read more
Sourcefn integration_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_integration_id: IntegrationId,
_guild_id: GuildId,
_application_id: Option<ApplicationId>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn integration_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_integration_id: IntegrationId,
_guild_id: GuildId,
_application_id: Option<ApplicationId>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild integration is deleted. Read more
Sourcefn stage_instance_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_stage_instance: StageInstance,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn stage_instance_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_stage_instance: StageInstance,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a stage instance is created. Read more
Sourcefn stage_instance_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_stage_instance: StageInstance,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn stage_instance_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_stage_instance: StageInstance,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a stage instance is updated. Read more
Sourcefn stage_instance_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_stage_instance: StageInstance,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn stage_instance_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_stage_instance: StageInstance,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a stage instance is deleted. Read more
Sourcefn thread_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread: GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn thread_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread: GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a thread is created or the current user is added
to a private thread. Read more
Sourcefn thread_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread: GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn thread_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread: GuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a thread is updated. Read more
Sourcefn thread_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread: PartialGuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn thread_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread: PartialGuildChannel,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a thread is deleted. Read more
Sourcefn thread_list_sync<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread_list_sync: ThreadListSyncEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn thread_list_sync<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread_list_sync: ThreadListSyncEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the current user gains access to a channel Read more
Sourcefn thread_member_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread_member: ThreadMember,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn thread_member_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread_member: ThreadMember,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when the
ThreadMember for the current user is updated. Read moreSourcefn thread_members_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread_members_update: ThreadMembersUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn thread_members_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_thread_members_update: ThreadMembersUpdateEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when anyone is added to or removed from a thread. If the current user does not have the
GatewayIntents::GUILDS,
then this event will only be sent if the current user was added to or removed from the thread. Read moreSourcefn guild_scheduled_event_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_event: ScheduledEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_scheduled_event_create<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_event: ScheduledEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a scheduled event is created. Read more
Sourcefn guild_scheduled_event_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_event: ScheduledEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_scheduled_event_update<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_event: ScheduledEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a scheduled event is updated. Read more
Sourcefn guild_scheduled_event_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_event: ScheduledEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_scheduled_event_delete<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_event: ScheduledEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a scheduled event is deleted. Read more
Sourcefn guild_scheduled_event_user_add<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_subscribed: GuildScheduledEventUserAddEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_scheduled_event_user_add<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_subscribed: GuildScheduledEventUserAddEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild member has subscribed to a scheduled event. Read more
Sourcefn guild_scheduled_event_user_remove<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_unsubscribed: GuildScheduledEventUserRemoveEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn guild_scheduled_event_user_remove<'life0, 'async_trait>(
&'life0 self,
_ctx: Context,
_unsubscribed: GuildScheduledEventUserRemoveEvent,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Dispatched when a guild member has unsubscribed from a scheduled event. Read more